;; Generated package description from breadcrumb.el  -*- no-byte-compile: t -*-
(define-package "breadcrumb" "1.0.0.0.20230905.171726" "project and imenu-based breadcrumb paths" '((emacs "28.1") (project "0.9.8")) :commit "41210dfd8f9ce72e3372ba8154c2300454857103" :url "https://elpa.gnu.org/packages/breadcrumb.html" :authors '(("João Távora" . "joaotavora@gmail.com")) :maintainer '("João Távora" . "joaotavora@gmail.com"))
